==> ejc-proequipmentcorp-impl-3.0.0-20221203.080427-232-sources.jar: com/ejianc/business/proequipmentcorppur/asset/service/impl/AssetAllotOutServiceImpl.java <==
package com.ejianc.business.proequipmentcorppur.asset.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.proequipmentcorppur.asset.bean.AssetAllotOutDetailEntity;
import com.ejianc.business.proequipmentcorppur.asset.bean.AssetAllotOutEntity;
import com.ejianc.business.proequipmentcorppur.asset.mapper.AssetAllotOutMapper;
import com.ejianc.business.proequipmentcorppur.asset.service.IAssetAllotOutService;
import com.ejianc.business.proequipmentcorppur.asset.vo.AssetAllotOutVO;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.procost.enums.SourceTypeEnum;
import com.ejianc.business.procost.vo.CostDetailVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 固定资产调出表
 * 
 * @author generator
 * 
 */
@Service("assetAllotOutService")
public class AssetAllotOutServiceImpl extends BaseServiceImpl<AssetAllotOutMapper, AssetAllotOutEntity> implements IAssetAllotOutService{
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    // 推送成本需要调用的接口 start
    @Autowired
    private ICostDetailApi costDetailApi;

    @Autowired
    private SessionManager sessionManager;

    @Override
    public CommonResponse<AssetAllotOutVO> pushCost(AssetAllotOutVO allotOutVO) {
        AssetAllotOutEntity allotOutEntity = baseMapper.selectById(allotOutVO.getId());
        if(CollectionUtils.isNotEmpty(allotOutVO.getAssetAllotOutDetailList())){
            List<AssetAllotOutDetailEntity> allotOutDetailEntitys = BeanMapper.mapList(allotOutVO.getAssetAllotOutDetailList(), AssetAllotOutDetailEntity.class);
            allotOutEntity.setAssetAllotOutDetailList(allotOutDetailEntitys);
        }
        super.saveOrUpdate(allotOutEntity, false);
        //推送数据
        this.costPush(allotOutEntity);
        return CommonResponse.success(BeanMapper.map(allotOutEntity, AssetAllotOutVO.class));
    }

    @Override
    public void costPush(AssetAllotOutEntity allotOutEntity) {
        logger.info("开始costPush");
        List<AssetAllotOutDetailEntity> allotOutDetailEntities = allotOutEntity.getAssetAllotOutDetailList();
        String newRelationFlag = "1";
        if(CollectionUtils.isNotEmpty(allotOutDetailEntities)){
            for (AssetAllotOutDetailEntity entity : allotOutDetailEntities) {
                if (null == entity.getSubjectId() || null == entity.getWbsId()) {
                    newRelationFlag = "0";
                    logger.info("getSubjectId"+entity.getSubjectId());
                    logger.info("getWbsId"+entity.getWbsId());
                    break;
                }
            }
        }
        if (ListUtil.isEmpty(allotOutDetailEntities)) {
            newRelationFlag = "0";
        }
        logger.info("newRelationFlag"+newRelationFlag);
        //更新是否关联
        LambdaUpdateWrapper<AssetAllotOutEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.in(AssetAllotOutEntity::getId, allotOutEntity.getId());
        updateWrapper.set(AssetAllotOutEntity::getRelationFlag, newRelationFlag);//(1:是，0：否)
        super.update(updateWrapper);

        //判断之前的单据是否关联
        String oldRelationFlag = allotOutEntity.getRelationFlag();
        //之前已关联
        if ("1".equals(oldRelationFlag)) {
            if ("1".equals(newRelationFlag)) {
                logger.info("之前已关联"+newRelationFlag);
                saveCost(allotOutEntity);
            }
            if (!"1".equals(newRelationFlag)) {
                //删除成本中心之前的数据
                logger.info("删除成本中心之前的数据-固定资产调出Id---{}",allotOutEntity.getId());
                CommonResponse<String> commonResponse = costDetailApi.deleteSubject(allotOutEntity.getId());
                logger.info("结果"+ JSONObject.toJSONString(commonResponse));
                if(!commonResponse.isSuccess()){
                    throw new BusinessException(commonResponse.getMsg());
                }
            }
        }
        //之前未关联
        if ("0".equals(oldRelationFlag)) {
            if ("1".equals(newRelationFlag)) {
                logger.info("之前未关联"+newRelationFlag);
                saveCost(allotOutEntity);
            }
        }
    }

    private void saveCost(AssetAllotOutEntity allotOutEntity) {
        //明细
        List<CostDetailVO> costDetailVOList = new ArrayList<>();
        List<AssetAllotOutDetailEntity> allotOutDetailList = allotOutEntity.getAssetAllotOutDetailList();
        if(CollectionUtils.isNotEmpty(allotOutDetailList)){
            for (AssetAllotOutDetailEntity entity : allotOutDetailList) {
                CostDetailVO costDetailVO = new CostDetailVO();
                costDetailVO.setSubjectId(entity.getSubjectId());
                costDetailVO.setSubjectCode(entity.getSubjectCode());
                costDetailVO.setSubjectName(entity.getSubjectName());
                costDetailVO.setWbsId(entity.getWbsId());
                costDetailVO.setWbsCode(entity.getWbsCode());
                costDetailVO.setWbsName(entity.getWbsName());
                costDetailVO.setSourceId(entity.getAllocatId());
                costDetailVO.setSourceDetailId(entity.getId());
                costDetailVO.setHappenTaxMny(entity.getAllocatDiffTaxMny());
                costDetailVO.setHappenMny(entity.getAllocatDiffMny());
                costDetailVO.setHappenDate(allotOutEntity.getOutDate());
                costDetailVO.setCreateUserName(sessionManager.getUserContext().getUserName());
                costDetailVO.setSourceType("ASSET_ALLOT_OUT");
                costDetailVO.setSourceTabType("ASSET_ALLOT_OUT_SUB");
                costDetailVO.setProjectId(allotOutEntity.getProjectId());
                //新加的
                costDetailVO.setSourceBillCode(allotOutEntity.getBillCode());
                costDetailVO.setSourceBillName(SourceTypeEnum.固定资产设备调出.getTypeName());
                costDetailVO.setSourceBillUrl("/ejc-proequipmentp-frontend/#/assetAllotOut/assetAllotOutCard?id="+allotOutEntity.getId());
                costDetailVOList.add(costDetailVO);
            }
        }

        //成本中心
        if (ListUtil.isNotEmpty(costDetailVOList)) {
            logger.info("推送数据--------"+JSONObject.toJSONString(costDetailVOList));
            CommonResponse<String> stringCommonResponse = costDetailApi.saveSubject(costDetailVOList);
            logger.info("推送结果--------"+JSONObject.toJSONString(stringCommonResponse));
            if (stringCommonResponse.isSuccess()) {
            } else {
                throw new BusinessException(stringCommonResponse.getMsg());
            }
        }

    }


}

==> ejc-proequipmentcorp-impl-3.0.0-20221228.101101-280-sources.jar: com/ejianc/business/proequipmentcorppur/asset/service/impl/AssetAllotOutServiceImpl.java <==
package com.ejianc.business.proequipmentcorppur.asset.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.proequipmentcorppur.asset.bean.AssetAllotOutDetailEntity;
import com.ejianc.business.proequipmentcorppur.asset.bean.AssetAllotOutEntity;
import com.ejianc.business.proequipmentcorppur.asset.bean.AssetAmortizeDetailEntity;
import com.ejianc.business.proequipmentcorppur.asset.bean.AssetAmortizeEntity;
import com.ejianc.business.proequipmentcorppur.asset.mapper.AssetAllotOutMapper;
import com.ejianc.business.proequipmentcorppur.asset.service.IAssetAllotOutService;
import com.ejianc.business.proequipmentcorppur.asset.service.IAssetAmortizeDetailService;
import com.ejianc.business.proequipmentcorppur.asset.service.IAssetAmortizeService;
import com.ejianc.business.proequipmentcorppur.asset.vo.AssetAllotOutVO;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.procost.enums.SourceTypeEnum;
import com.ejianc.business.procost.vo.CostDetailVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 固定资产调出表
 * 
 * @author generator
 * 
 */
@Service("assetAllotOutService")
public class AssetAllotOutServiceImpl extends BaseServiceImpl<AssetAllotOutMapper, AssetAllotOutEntity> implements IAssetAllotOutService{
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    // 推送成本需要调用的接口 start
    @Autowired
    private ICostDetailApi costDetailApi;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IAssetAmortizeService assetAmortizeService;
    @Autowired
    private IAssetAmortizeDetailService assetAmortizeDetailService;

    @Override
    public CommonResponse<AssetAllotOutVO> pushCost(AssetAllotOutVO allotOutVO) {
        AssetAllotOutEntity allotOutEntity = baseMapper.selectById(allotOutVO.getId());
        if(CollectionUtils.isNotEmpty(allotOutVO.getAssetAllotOutDetailList())){
            List<AssetAllotOutDetailEntity> allotOutDetailEntitys = BeanMapper.mapList(allotOutVO.getAssetAllotOutDetailList(), AssetAllotOutDetailEntity.class);
            allotOutEntity.setAssetAllotOutDetailList(allotOutDetailEntitys);
        }
        super.saveOrUpdate(allotOutEntity, false);
        //推送数据
        this.costPush(allotOutEntity);
        return CommonResponse.success(BeanMapper.map(allotOutEntity, AssetAllotOutVO.class));
    }

    @Override
    public void costPush(AssetAllotOutEntity allotOutEntity) {
        logger.info("开始costPush");
        List<AssetAllotOutDetailEntity> allotOutDetailEntities = allotOutEntity.getAssetAllotOutDetailList();
        String newRelationFlag = "1";
        if(CollectionUtils.isNotEmpty(allotOutDetailEntities)){
            for (AssetAllotOutDetailEntity entity : allotOutDetailEntities) {
                if (null == entity.getSubjectId() || null == entity.getWbsId()) {
                    newRelationFlag = "0";
                    logger.info("getSubjectId"+entity.getSubjectId());
                    logger.info("getWbsId"+entity.getWbsId());
                    break;
                }
            }
        }
        if (ListUtil.isEmpty(allotOutDetailEntities)) {
            newRelationFlag = "0";
        }
        logger.info("newRelationFlag"+newRelationFlag);
        //更新是否关联
        LambdaUpdateWrapper<AssetAllotOutEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.in(AssetAllotOutEntity::getId, allotOutEntity.getId());
        updateWrapper.set(AssetAllotOutEntity::getRelationFlag, newRelationFlag);//(1:是，0：否)
        super.update(updateWrapper);

        //判断之前的单据是否关联
        String oldRelationFlag = allotOutEntity.getRelationFlag();
        //之前已关联
        if ("1".equals(oldRelationFlag)) {
            if ("1".equals(newRelationFlag)) {
                logger.info("之前已关联"+newRelationFlag);
                saveCost(allotOutEntity);
            }
            if (!"1".equals(newRelationFlag)) {
                //删除成本中心之前的数据
                logger.info("删除成本中心之前的数据-固定资产调出Id---{}",allotOutEntity.getId());
                CommonResponse<String> commonResponse = costDetailApi.deleteSubject(allotOutEntity.getId());
                logger.info("结果"+ JSONObject.toJSONString(commonResponse));
                if(!commonResponse.isSuccess()){
                    throw new BusinessException(commonResponse.getMsg());
                }
            }
        }
        //之前未关联
        if ("0".equals(oldRelationFlag)) {
            if ("1".equals(newRelationFlag)) {
                logger.info("之前未关联"+newRelationFlag);
                saveCost(allotOutEntity);
            }
        }
    }

    @Override
    public CommonResponse<String> getEquipmentAmortize(List<String> leaveFactoryCodeList) {
        QueryParam param = new QueryParam();
        param.getParams().put("leaveFactoryCode", new Parameter(QueryParam.IN, leaveFactoryCodeList));
        List<AssetAmortizeDetailEntity> assetAmortizeDetailEntityList = assetAmortizeDetailService.queryList(param);
        if (CollectionUtils.isEmpty(assetAmortizeDetailEntityList)){
            return CommonResponse.success("设备可以选择！");
        }else {
            List<Long> assetAmortizePidList = assetAmortizeDetailEntityList.stream().map(AssetAmortizeDetailEntity::getPid).collect(Collectors.toList());
            QueryParam assetParam = new QueryParam();
            assetParam.getParams().put("id", new Parameter(QueryParam.IN, assetAmortizePidList));
            assetParam.getOrderMap().put("create_time", QueryParam.DESC);
            List<AssetAmortizeEntity> assetAmortizeEntityList = assetAmortizeService.queryList(assetParam);
            AssetAmortizeEntity assetAmortizeEntity = assetAmortizeEntityList.get(0);
            if (!(BillStateEnum.PASSED_STATE.getBillStateCode().equals(assetAmortizeEntity.getBillState()) || BillStateEnum.COMMITED_STATE.getBillStateCode().equals(assetAmortizeEntity.getBillState()))){
                //非已提交、审批通过状态 的设备返回
                List<String> leaveFactoryCodes = assetAmortizeDetailEntityList.stream().filter(item -> item.getPid().equals(assetAmortizeEntity.getId())).map(AssetAmortizeDetailEntity::getLeaveFactoryCode).collect(Collectors.toList());
                return CommonResponse.error("设备" + JSONObject.toJSONString(leaveFactoryCodes) + "设备摊销未完成，请完成之后再选择！");
            }else {
                return CommonResponse.success("设备可以选择！");
            }
        }
    }

    private void saveCost(AssetAllotOutEntity allotOutEntity) {
        //明细
        List<CostDetailVO> costDetailVOList = new ArrayList<>();
        List<AssetAllotOutDetailEntity> allotOutDetailList = allotOutEntity.getAssetAllotOutDetailList();
        if(CollectionUtils.isNotEmpty(allotOutDetailList)){
            for (AssetAllotOutDetailEntity entity : allotOutDetailList) {
                CostDetailVO costDetailVO = new CostDetailVO();
                costDetailVO.setSubjectId(entity.getSubjectId());
                costDetailVO.setSubjectCode(entity.getSubjectCode());
                costDetailVO.setSubjectName(entity.getSubjectName());
                costDetailVO.setWbsId(entity.getWbsId());
                costDetailVO.setWbsCode(entity.getWbsCode());
                costDetailVO.setWbsName(entity.getWbsName());
                costDetailVO.setSourceId(entity.getAllocatId());
                costDetailVO.setSourceDetailId(entity.getId());
                costDetailVO.setHappenTaxMny(entity.getAllocatDiffTaxMny());
                costDetailVO.setHappenMny(entity.getAllocatDiffMny());
                costDetailVO.setHappenDate(allotOutEntity.getOutDate());
                costDetailVO.setCreateUserName(sessionManager.getUserContext().getUserName());
                costDetailVO.setSourceType("ASSET_ALLOT_OUT");
                costDetailVO.setSourceTabType("ASSET_ALLOT_OUT_SUB");
                costDetailVO.setProjectId(allotOutEntity.getProjectId());
                //新加的
                costDetailVO.setSourceBillCode(allotOutEntity.getBillCode());
                costDetailVO.setSourceBillName(SourceTypeEnum.固定资产设备调出.getTypeName());
                costDetailVO.setSourceBillUrl("/ejc-proequipmentp-frontend/#/assetAllotOut/assetAllotOutCard?id="+allotOutEntity.getId());
                costDetailVOList.add(costDetailVO);
            }
        }

        //成本中心
        if (ListUtil.isNotEmpty(costDetailVOList)) {
            logger.info("推送数据--------"+JSONObject.toJSONString(costDetailVOList));
            CommonResponse<String> stringCommonResponse = costDetailApi.saveSubject(costDetailVOList);
            logger.info("推送结果--------"+JSONObject.toJSONString(stringCommonResponse));
            if (stringCommonResponse.isSuccess()) {
            } else {
                throw new BusinessException(stringCommonResponse.getMsg());
            }
        }

    }


}
